@@ -86,6 +86,7 @@ class WKFSAdapter:
         transaction_data_base64 = base64_bytes.decode("utf-8")
         payload["transactionData"] = transaction_data_base64
         payload["callbackPath"] = callback_url
+        packet_id = None
 
         wkfs_package_name = None
 
@@ -94,10 +95,12 @@ class WKFSAdapter:
 
             if package_name == config_package_name:
                 wkfs_package_name = package.get("wkfs_package_name")
+                packet_id = package.get("package_or_packet")
                 break
+
         packages = []
         package = {}
-        package["id"] = f"expere://{wkfs_id}/{wkfs_package_name}"
+        package["id"] = f"expere://{wkfs_id}/{packet_id}"
         package["name"] = wkfs_package_name
         packages.append(package)
         payload["options"] = options
