@@ -6,7 +6,7 @@ BASE_DIR = Path(__file__).resolve().parent
 
 LOGGING_CONFIG = {
     "version": 1,
-    "disable_existing_loggers": True,
+    "disable_existing_loggers": False,
     "formatters": {
         "development": {
             "format": (
